library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;

entity bcd2seg is
	port (bcd0_1 : in std_logic;
			bcd0_2 : in std_logic;
			bcd0_4 : in std_logic;
			bcd0_8 : in std_logic;
			bcd1_1 : in std_logic;
			bcd1_2 : in std_logic;
			bcd1_4 : in std_logic;
			bcd1_8 : in std_logic;
			bcd2_1 : in std_logic;
			bcd2_2 : in std_logic;
			seg0_d0 : out std_logic;
			seg0_d1 : out std_logic;
			seg0_d2 : out std_logic;
			seg0_d3 : out std_logic;
			seg0_d4 : out std_logic;
			seg0_d5 : out std_logic;
			seg0_d6 : out std_logic;
			seg1_d0 : out std_logic;
			seg1_d1 : out std_logic;
			seg1_d2 : out std_logic;
			seg1_d3 : out std_logic;
			seg1_d4 : out std_logic;
			seg1_d5 : out std_logic;
			seg1_d6 : out std_logic;
			seg2_d0 : out std_logic;
			seg2_d1 : out std_logic;
			seg2_d2 : out std_logic;
			seg2_d3 : out std_logic;
			seg2_d4 : out std_logic;
			seg2_d5 : out std_logic;
			seg2_d6 : out std_logic
			);
end entity bcd2seg;

architecture rtl of bcd2seg is
type seg_table_type is array(0 to 15) of integer range 0 to 127;
constant seg_table : seg_table_type := (64, 121, 36, 48, 25, 18, 2, 120, 0, 16, 63, 63, 63, 63, 63, 63);

signal bcd0, bcd1, bcd2 : unsigned(3 downto 0);
signal seg0, seg1, seg2 : std_logic_vector (6 downto 0);
begin

	bcd0 <= bcd0_8 & bcd0_4 & bcd0_2 & bcd0_1;
	bcd1 <= bcd1_8 & bcd1_4 & bcd1_2 & bcd1_1;
	bcd2 <= "00"& bcd2_2 & bcd2_1;

	seg0 <= std_logic_vector(to_unsigned(seg_table(to_integer(bcd0)),7));
	seg1 <= std_logic_vector(to_unsigned(seg_table(to_integer(bcd1)),7));
	seg2 <= std_logic_vector(to_unsigned(seg_table(to_integer(bcd2)),7));

	(seg0_d6, seg0_d5, seg0_d4, seg0_d3, seg0_d2, seg0_d1, seg0_d0) <= seg0;
	(seg1_d6, seg1_d5, seg1_d4, seg1_d3, seg1_d2, seg1_d1, seg1_d0) <= seg1;
	(seg2_d6, seg2_d5, seg2_d4, seg2_d3, seg2_d2, seg2_d1, seg2_d0) <= seg2;
	
end architecture rtl;
