# Filename:     tb_bin8_to_bcd10.do
# Filetype:     Modelsim Script File
# Date:         26 sep 2014
# Update:       -
# Description:  Script File For Automatic Simulation
# Author:       J. op den Brouw
# State:        Lab
# Error:        -
# Version:      1.1
# Copyright:    (c)2014, De Haagse Hogeschool

# Transcript on, we see output
transcript on

# Recreate working directory
if {[file exists rtl_work]} {
	vdel -lib rtl_work -all
}
vlib rtl_work
vmap work rtl_work

# Loop through all the VHDL files and compile them
foreach vhd_file [ glob *.vhd ] {
	#puts $vhd_file
	vcom -93 -work work $vhd_file
}

# Start the simulator
vsim -t 1ns -L rtl_work -L work -voptargs="+acc" bin8_to_bcd10

# Log all signals in the design, good if the number
# of signals is small.
add log -r *

# Add all toplevel signals
# Add a number of signals of the simulated design
# Add binary inputs
add list -nodelta -label SW7 sw7
add list -nodelta -label SW6 sw6
add list -nodelta -label SW5 sw5
add list -nodelta -label SW4 sw4
add list -nodelta -width 3 -label SW3 sw3
add list -nodelta -label SW2 sw2
add list -nodelta -label SW1 sw1
add list -nodelta -label SW0 sw0

# Display BCD outputs
add list -nodelta -width 5 -label bcd2_2 b2v_bcd_2_seven_segment/bcd2_2
add list -nodelta -label bcd2_1 b2v_bcd_2_seven_segment/bcd2_1
add list -nodelta -width 3 -label bcd1_8 b2v_bcd_2_seven_segment/bcd1_8
add list -nodelta -label bcd1_4 b2v_bcd_2_seven_segment/bcd1_4
add list -nodelta -label bcd1_2 b2v_bcd_2_seven_segment/bcd1_2
add list -nodelta -label bcd1_1 b2v_bcd_2_seven_segment/bcd1_1
add list -nodelta -width 3 -label bcd0_8 b2v_bcd_2_seven_segment/bcd0_8
add list -nodelta -label bcd0_4 b2v_bcd_2_seven_segment/bcd0_4
add list -nodelta -label bcd0_2 b2v_bcd_2_seven_segment/bcd0_2
add list -nodelta -label bcd0_1 b2v_bcd_2_seven_segment/bcd0_1

# Display binary and BCD as hex numbers instead of bits
add list -nodelta -width 8 -label HEX -hex {HEX {SW7 SW6 SW5 SW4 SW3 SW2 SW1 SW0}}
add list -nodelta -width 5 -label DEC -hex {DEC {b2v_bcd_2_seven_segment/bcd2_2 b2v_bcd_2_seven_segment/bcd2_1 b2v_bcd_2_seven_segment/bcd1_8 b2v_bcd_2_seven_segment/bcd1_4 b2v_bcd_2_seven_segment/bcd1_2 b2v_bcd_2_seven_segment/bcd1_1 b2v_bcd_2_seven_segment/bcd0_8 b2v_bcd_2_seven_segment/bcd0_4 b2v_bcd_2_seven_segment/bcd0_2 b2v_bcd_2_seven_segment/bcd0_1}}

# Open List window
noview Wave
noview Signals
noview Structure
view list

# Apply stimuli
force SW0 0 0, 1 20   -repeat 40    -cancel 5120
force SW1 0 0, 1 40   -repeat 80    -cancel 5120
force SW2 0 0, 1 80   -repeat 160   -cancel 5120
force SW3 0 0, 1 160  -repeat 320   -cancel 5120
force SW4 0 0, 1 320  -repeat 640   -cancel 5120
force SW5 0 0, 1 640  -repeat 1280  -cancel 5120
force SW6 0 0, 1 1280 -repeat 2560  -cancel 5120
force SW7 0 0, 1 2560 -repeat 5120  -cancel 5120


# Run simulation for 5120 ns
run 5100 ns
